@@ -2,13 +2,13 @@ package Mail::DMARC::Report::Send::HTTP;
 use strict;
 use warnings;
 
-our $VERSION = '1.20200113';
+our $VERSION = '1.20200114';
 
 use Carp;
 
 #use Data::Dumper;
 #use HTTP::Tiny;     # a possibility
-use Net::HTTP;
+#use Net::HTTP;      # lazy loaded in 'post'
 
 use parent 'Mail::DMARC::Base';
 
@@ -18,8 +18,10 @@ sub post {
     carp "http send feature not complete!";
     return;
 
-    # TODO: test
 ## no critic (Unreachable)
+    # TODO: test against real HTTP server, validate HTTP response
+    eval "require Net::HTTP" or return;
+
     my $ver = $Mail::DMARC::Base::VERSION;
     my $s = Net::HTTP->new( Host => $uri->host ) or croak $@;
     $s->write_request(
@@ -51,7 +53,7 @@ Mail::DMARC::Report::Send::HTTP - utility methods to send reports by HTTP
 
 =head1 VERSION
 
-version 1.20200113
+version 1.20200114
 
 =head1 12.2.2. HTTP
 
